==> dl.php?src=linea21_1_8.zip: linea21/languages/en/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "projects";

/*	nommage des modules
 *  	*/
$lang['project']['name']="project";
$lang['project']['confirm_add'] = "Project successfully added\n";
$lang['project']['confirm_mod'] = "Project successfully updated\n";
$lang['project']['confirm_sup'] ="Project successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Add a new ".$lang['project']['name'];
$lang['project']['mod']= "Edit ".$lang['project']['name'];
$lang['project']['sup']= "Delete ".$lang['project']['name'];
$lang['project']['det']= ucfirst($lang['project']['name']). " details";
$lang['project']['list']= "View projects";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']='Add data about the new '.$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="name";
$lang['project']['goal']="goal(s)";
$lang['project']['description']="description";
$lang['project']['body']="body";
$lang['project']['budget']="budget (in €)";
$lang['project']['budget_comment']="budget - complement";
$lang['project']['elected']="elected referent(s)";
$lang['project']['manager']="manager(s)";
$lang['project']['coordinator']="coordinator";
$lang['project']['team']="team project";
$lang['project']['partners']="partners";
$lang['project']['begin_date']="starting date";
$lang['project']['estimated_date']="estimated end date";
$lang['project']['end_date']="effective end date";
$lang['project']['progression']="progression (%)";
$lang['project']['parent']="parent project";
$lang['project']['sub-projects']="sub-projects";
$lang['project']['priority']="priority";
$lang['project']['theme']="theme";
$lang['project']['workshop']="workgroup";
$lang['project']['comment']="comment";
$lang['project']['sdi']="indicators";
$lang['project']['scale']="scale";
$lang['project']['author']="author";
$lang['project']['statut']='status';

$lang['project']['steering_title']='Sterring / animation';
$lang['project']['calendar_title']='Calendar';
$lang['project']['budget_title']='Budget';

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" latest additions";
$lang['project']['qb_titlemod']=" latest modifications";
$lang['project']['qb_titlesup']=" latest deletions";
$lang['project']['qb_titlepubli']=' latest publications';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Choose in this list --";

$lang['project']['nb_total']='projects in database.';
$lang['project']['statut_filter']='Display by status';
$lang['project']['all']='Display list';
$lang['project']['noresult']='There is no project with this criteria ';

/*	messages
 *  	*/
$lang['project']['no_name']='Name is required';
$lang['project']['no_description']='Description is required';
$lang['project']['no_body']='Body is required';
$lang['project']['no_scale']='Scale is required';
$lang['project']['no_priority']='Priority is required';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.';
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application';
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions';
$lang['project']['budget_integer']='Budget : an integer value is required';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="To add a project, please insert the required informations in the form above";
$lang['project']['help_add2']='After submitting the form, check your data in the summary';
$lang['project']['help_add3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['project']['help_list1']='Click on project name to display more informations';
$lang['project']['help_list2']='Delete project by clicking on the delete icon linked in';
$lang['project']['help_list3']='Edit project by clicking on the edit icon linked in';
$lang['project']['help_list4']='Click \'add a project\' button for adding project';
$lang['project']['help_list5']="To perform search on projects only, just click the 'search' link";

$lang['project']['help_mod1']='To edit a project, please insert the required informations in the form above';
$lang['project']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['project']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';

$lang['project']['help_det1']="To access the parent project, click on its name";
$lang['project']['help_det2']='Delete project by clicking on the delete icon linked in';
$lang['project']['help_det3']='Edit project by clicking on the edit icon linked in';

$lang['project']['help_sup1']="Caution, if the current project contains sub-projects they will not be automatically deleted";
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/en/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "projects";

/*	nommage des modules
 *  	*/
$lang['project']['name']="project";
$lang['project']['confirm_add'] = "Project successfully added\n";
$lang['project']['confirm_mod'] = "Project successfully updated\n";
$lang['project']['confirm_sup'] ="Project successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Add a new ".$lang['project']['name'];
$lang['project']['mod']= "Edit ".$lang['project']['name'];
$lang['project']['sup']= "Delete ".$lang['project']['name'];
$lang['project']['det']= ucfirst($lang['project']['name']). " details";
$lang['project']['list']= "View projects";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']='Add data about the new '.$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="name";
$lang['project']['goal']="goal(s)";
$lang['project']['description']="description";
$lang['project']['body']="body";
$lang['project']['budget']="budget (in €)";
$lang['project']['budget_comment']="budget - complement";
$lang['project']['elected']="elected referent(s)";
$lang['project']['manager']="manager(s)";
$lang['project']['coordinator']="coordinator";
$lang['project']['team']="team project";
$lang['project']['partners']="partners";
$lang['project']['begin_date']="starting date";
$lang['project']['estimated_date']="estimated end date";
$lang['project']['end_date']="effective end date";
$lang['project']['progression']="progression (%)";
$lang['project']['parent']="parent project";
$lang['project']['sub-projects']="sub-projects";
$lang['project']['priority']="priority";
$lang['project']['level']="level";
$lang['project']['workshop']="workgroup";
$lang['project']['comment']="comment";
$lang['project']['sdi']="indicators";
$lang['project']['scale']="scale";
$lang['project']['author']="author";
$lang['project']['statut']='status';
$lang['project']['add_indicator']="add an indicator";
$lang['project']['add_indicator_value']="enter an indicator value";
$lang['project']['completion']="completion";
$lang['project']['report']="Export / generate report";
$lang['project']['steering_title']='Sterring / animation';
$lang['project']['calendar_title']='Calendar';
$lang['project']['budget_title']='Budget';
$lang['project']['finalities']='Finalities';


// views
$lang['project']['level_view']='Ordered by levels';
$lang['project']['flat_view']='Flat view';
$lang['project']['finality_view']='Ordered by finality';


/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" latest additions";
$lang['project']['qb_titlemod']=" latest modifications";
$lang['project']['qb_titlesup']=" latest deletions";
$lang['project']['qb_titlepubli']=' latest publications';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Choose in this list --";

$lang['project']['nb_total']='projects in database.';
$lang['project']['statut_filter']='Display by status';
$lang['project']['all']='Display list';
$lang['project']['noresult']='There is no project with this criteria ';
$lang['project']['session-stored']="%s projects are stored in session";

/*	messages
 *  	*/
$lang['project']['no_name']='Name is required';
$lang['project']['no_description']='Description is required';
$lang['project']['no_body']='Body is required';
$lang['project']['no_scale']='Scale is required';
$lang['project']['no_level']='Level is required';
$lang['project']['no_priority']='Priority is required';
$lang['project']['progression_error']='Progression indicator muste take a value between 0 and 100.';
$lang['project']['incorrect_user']='Given manager \'%s\' is unknown from the application';
$lang['project']['incorrect_userperm']='Given manager  \'%s\' has not required permissions';
$lang['project']['budget_integer']='Budget : an integer value is required';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';
$lang['project']['inconsistent_date']='Given dates seem to be inconsistent. Please, change them.';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="To add a project, please insert the required informations in the form above";
$lang['project']['help_add2']='After submitting the form, check your data in the summary';
$lang['project']['help_add3']='After checking summary, click the \'review settings\' button to make new changes';

$lang['project']['help_list1']='Click on project name to display more informations';
$lang['project']['help_list2']='Delete project by clicking on the delete icon linked in';
$lang['project']['help_list3']='Edit project by clicking on the edit icon linked in';
$lang['project']['help_list4']='Click \'add a project\' button for adding project';
$lang['project']['help_list5']="To perform search on projects only, just click the 'search' link";

$lang['project']['help_mod1']='To edit a project, please insert the required informations in the form above';
$lang['project']['help_mod2']='Once the form submitted, check your data in the summary';
$lang['project']['help_mod3']='Once the summary displayed, click the \'review settings\' button if you need to make new changes';

$lang['project']['help_det1']="To access the parent project, click on its name";
$lang['project']['help_det2']='Delete project by clicking on the delete icon linked in';
$lang['project']['help_det3']='Edit project by clicking on the edit icon linked in';

$lang['project']['help_sup1']="Caution, if the current project contains sub-projects they will not be automatically deleted";
?>
